import sys
import os
import requests
import pandas as pd
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.api.kpl.common.kpl_common_api as kpl_common_api

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)


# 精选板块指数
def best_choose():
    return kpl_common_api.get_plate_index(kpl_common_api.BEST_CHOOSE)


# 精选股票组成
# Order 排序参数
# st 分页最大数量
# index 股票排名index
def best_choose_stock(plate_code):
    return kpl_common_api.plate_detail_info(plate_code)


# 精选股票 组成详情 子版块
def best_choose_sub_index(plateId):
    url = (
            f" https://apphq.longhuvip.com/w1/api/index.php?DEnd=&Date=&PhoneOSNew=2"
            f"&PlateID=" + plateId +
            f"&VerSion=5.11.0.3&a=SonPlate_Info&apiv=w33&c=ZhiShuRanking")
    headers = {
        "User-Agent": "Content-Type: application/x-www-form-urlencoded; charset=utf-8"
    }
    r = requests.post(url, headers=headers)
    data_json = r.json()
    data_concept = data_json['List']
    data_df = pd.DataFrame(data_concept)
    if data_frame_util.is_empty(data_df):
        return None
    data_df.columns = [
        "plate_code",
        "plate_name",
        "heat_score"]
    return data_df


if __name__ == '__main__':
    # while True:
    #     df = best_choose()
    #     df = df[['plate_code', 'plate_name', 'heat_score', 'chg', 'amount']]
    #     print(df)
    df = best_choose_sub_index('801218')
    print(df)
    # df_detail = best_choose_stock('801511')
    # print(df_detail)
    # df_detail = df_detail.sort_values(by=['chg'], ascending=False)
    # print(df_detail)



import sys
import os
file_path = os.path.abspath(__file__)
end = file_path.index('mns') +14
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.api.kpl.common.kpl_common_api as kpl_common_api


def get_concept_index():
    return kpl_common_api.get_plate_index(kpl_common_api.CONCEPT)


def concept_index_detail(concept_code):
    return kpl_common_api.plate_detail_info(concept_code)


if __name__ == '__main__':
    df_concept = get_concept_index()
    print(df_concept)
    df_concept_detail = concept_index_detail('801476')
    print(df_concept_detail)



import os
import sys

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.component.k_line.clean.k_line_param import sh_small_normal_k_line_param
import pandas as pd
from io import StringIO
from loguru import logger


def recent_day_zt_check(real_time_quotes_now_sh):
    # 排除昨日涨停的股票
    real_time_quotes_now_sh.loc[
        real_time_quotes_now_sh['daily01'] >= sh_small_normal_k_line_param['zt_chg'], 'exclude'] = True
    real_time_quotes_now_sh = handle_02_day_zt(real_time_quotes_now_sh.copy())
    real_time_quotes_now_sh = handle_03_day_zt(real_time_quotes_now_sh.copy())
    real_time_quotes_now_sh = handle_04_day_zt(real_time_quotes_now_sh.copy())
    real_time_quotes_now_sh = handle_05_day_zt(real_time_quotes_now_sh.copy())

    return real_time_quotes_now_sh


def handle_02_day_zt(real_time_quotes_now_sh):
    real_time_quotes_now_sh_02_zt = real_time_quotes_now_sh.loc[
        real_time_quotes_now_sh['daily02'] >= sh_small_normal_k_line_param['zt_chg']]
    if data_frame_util.is_empty(real_time_quotes_now_sh_02_zt):
        return real_time_quotes_now_sh

    for stock_one in real_time_quotes_now_sh_02_zt.itertuples():
        try:
            # 当前收盘价格
            close_last = stock_one.close_last

            history_data = stock_one.history_data
            history_data_df = pd.read_csv(StringIO(history_data), delim_whitespace=True)
            daily_02_df = history_data_df.iloc[1:2]
            daily_02_close = list(daily_02_df['close'])[0]
            # 当前收盘价格高于02日涨停价格 排除
            if close_last > daily_02_close:
                real_time_quotes_now_sh.loc[
                    real_time_quotes_now_sh['symbol'] >= stock_one.symbol, 'exclude'] = True

        except BaseException as e:
            logger.error("处理02日涨停数据异常:{},{}", e, stock_one.symbol)
    return real_time_quotes_now_sh


def handle_03_day_zt(real_time_quotes_now_sh):
    # 只有03日涨停
    real_time_quotes_now_sh_03_zt_one_day = real_time_quotes_now_sh.loc[
        (real_time_quotes_now_sh['daily03'] >= sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily02'] < sh_small_normal_k_line_param['zt_chg'])]
    # 02 03日涨停
    real_time_quotes_now_sh_03_zt_two_day = real_time_quotes_now_sh.loc[
        (real_time_quotes_now_sh['daily03'] >= sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily02'] >= sh_small_normal_k_line_param['zt_chg'])]

    if data_frame_util.is_empty(real_time_quotes_now_sh_03_zt_one_day) and data_frame_util.is_empty(
            real_time_quotes_now_sh_03_zt_two_day):
        return real_time_quotes_now_sh

    for stock_one in real_time_quotes_now_sh_03_zt_one_day.itertuples():
        try:
            # 当前收盘价格
            close_last = stock_one.close_last

            history_data = stock_one.history_data
            history_data_df = pd.read_csv(StringIO(history_data), delim_whitespace=True)
            daily_03_df = history_data_df.iloc[2:3]
            daily_03_close = list(daily_03_df['close'])[0]
            # 当前收盘价格高于03日涨停价格 排除
            if close_last > daily_03_close:
                real_time_quotes_now_sh.loc[
                    real_time_quotes_now_sh['symbol'] >= stock_one.symbol, 'exclude'] = True

        except BaseException as e:
            logger.error("处理03日涨停数据异常:{},{}", e, stock_one.symbol)

    for stock_one_two in real_time_quotes_now_sh_03_zt_two_day.itertuples():
        try:
            # 当前收盘价格
            close_last = stock_one_two.close_last

            history_data = stock_one_two.history_data
            history_data_df = pd.read_csv(StringIO(history_data), delim_whitespace=True)
            daily_02_df = history_data_df.iloc[1:2]
            daily_02_close = list(daily_02_df['close'])[0]
            # 当前收盘价格高于02日涨停价格 排除
            if close_last > daily_02_close:
                real_time_quotes_now_sh.loc[
                    real_time_quotes_now_sh['symbol'] >= stock_one_two.symbol, 'exclude'] = True

        except BaseException as e:
            logger.error("处理03日涨停数据异常:{},{}", e, stock_one_two.symbol)
    return real_time_quotes_now_sh


def handle_04_day_zt(real_time_quotes_now_sh):
    real_time_quotes_now_sh_04_zt = real_time_quotes_now_sh.loc[
        (real_time_quotes_now_sh['daily04'] >= sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily03'] < sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily02'] < sh_small_normal_k_line_param['zt_chg'])]
    # 只有04日涨停
    for stock_one in real_time_quotes_now_sh_04_zt.itertuples():
        try:
            # 当前收盘价格
            close_last = stock_one.close_last

            history_data = stock_one.history_data
            history_data_df = pd.read_csv(StringIO(history_data), delim_whitespace=True)
            daily_04_df = history_data_df.iloc[3:4]
            daily_04_close = list(daily_04_df['close'])[0]
            # 当前收盘价格高于04日涨停价格 排除
            if close_last > daily_04_close:
                real_time_quotes_now_sh.loc[
                    real_time_quotes_now_sh['symbol'] >= stock_one.symbol, 'exclude'] = True

        except BaseException as e:
            logger.error("处理03日涨停数据异常:{},{}", e, stock_one.symbol)

    real_time_quotes_now_sh_04_03 = real_time_quotes_now_sh.loc[
        (real_time_quotes_now_sh['daily04'] >= sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily03'] >= sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily02'] < sh_small_normal_k_line_param['zt_chg'])]

    # 03 04日涨停
    for stock_one_03_04 in real_time_quotes_now_sh_04_03.itertuples():
        try:
            # 当前收盘价格
            close_last = stock_one_03_04.close_last

            history_data = stock_one_03_04.history_data
            history_data_df = pd.read_csv(StringIO(history_data), delim_whitespace=True)
            daily_03_df = history_data_df.iloc[2:3]
            daily_03_close = list(daily_03_df['close'])[0]
            # 当前收盘价格高于03日涨停价格 排除
            if close_last > daily_03_close:
                real_time_quotes_now_sh.loc[
                    real_time_quotes_now_sh['symbol'] >= stock_one_03_04.symbol, 'exclude'] = True

        except BaseException as e:
            logger.error("处理03日涨停数据异常:{},{}", e, stock_one_03_04.symbol)
    # 04 02 涨停
    real_time_quotes_now_sh_04_02_zt = real_time_quotes_now_sh.loc[
        (real_time_quotes_now_sh['daily04'] >= sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily03'] < sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily02'] >= sh_small_normal_k_line_param['zt_chg'])]

    if data_frame_util.is_not_empty(real_time_quotes_now_sh_04_02_zt):
        real_time_quotes_now_sh.loc[
            real_time_quotes_now_sh['symbol'].isin(list(real_time_quotes_now_sh_04_02_zt['symbol'])),
            'exclude'] = True

    # 04 03 02 涨停
    real_time_quotes_now_sh_04_03_02_zt = real_time_quotes_now_sh.loc[
        (real_time_quotes_now_sh['daily04'] >= sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily03'] >= sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily02'] >= sh_small_normal_k_line_param['zt_chg'])]

    if data_frame_util.is_not_empty(real_time_quotes_now_sh_04_03_02_zt):
        real_time_quotes_now_sh.loc[
            real_time_quotes_now_sh['symbol'].isin(list(real_time_quotes_now_sh_04_03_02_zt['symbol'])),
            'exclude'] = True

    return real_time_quotes_now_sh


def handle_05_day_zt(real_time_quotes_now_sh):
    real_time_quotes_now_sh_05_zt = real_time_quotes_now_sh.loc[
        (real_time_quotes_now_sh['daily05'] >= sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily04'] < sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily03'] < sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily02'] < sh_small_normal_k_line_param['zt_chg'])]
    # 只有05日涨停
    for stock_one in real_time_quotes_now_sh_05_zt.itertuples():
        try:
            # 当前收盘价格
            close_last = stock_one.close_last

            history_data = stock_one.history_data
            history_data_df = pd.read_csv(StringIO(history_data), delim_whitespace=True)
            daily_05_df = history_data_df.iloc[4:5]
            daily_05_close = list(daily_05_df['close'])[0]
            # 当前收盘价格高于05日涨停价格 排除
            if close_last > daily_05_close:
                real_time_quotes_now_sh.loc[
                    real_time_quotes_now_sh['symbol'] >= stock_one.symbol, 'exclude'] = True

        except BaseException as e:
            logger.error("处理05日涨停数据异常:{},{}", e, stock_one.symbol)
    real_time_quotes_now_sh_05_04_zt = real_time_quotes_now_sh.loc[
        (real_time_quotes_now_sh['daily05'] >= sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily04'] >= sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily03'] < sh_small_normal_k_line_param['zt_chg'])
        & (real_time_quotes_now_sh['daily02'] < sh_small_normal_k_line_param['zt_chg'])]

    # 04 05日涨停
    for stock_one_04_05 in real_time_quotes_now_sh_05_04_zt.itertuples():
        try:
            # 当前收盘价格
            close_last = stock_one_04_05.close_last

            history_data = stock_one_04_05.history_data
            history_data_df = pd.read_csv(StringIO(history_data), delim_whitespace=True)
            daily_04_df = history_data_df.iloc[3:4]
            daily_04_close = list(daily_04_df['close'])[0]
            # 当前收盘价格高于04日涨停价格 排除
            if close_last > daily_04_close:
                real_time_quotes_now_sh.loc[
                    real_time_quotes_now_sh['symbol'] >= stock_one_04_05.symbol, 'exclude'] = True

        except BaseException as e:
            logger.error("处理05日涨停数据异常:{},{}", e, stock_one_04_05.symbol)

    # 最近五天有三板以上的
    real_time_quotes_now_sh_05_exclude = real_time_quotes_now_sh.loc[
        ((real_time_quotes_now_sh['daily05'] >=
          sh_small_normal_k_line_param['zt_chg'])
         & (real_time_quotes_now_sh['daily04'] >=
            sh_small_normal_k_line_param['zt_chg'])
         & (real_time_quotes_now_sh['daily03'] >=
            sh_small_normal_k_line_param['zt_chg'])
         & (real_time_quotes_now_sh['daily02'] <
            sh_small_normal_k_line_param['zt_chg']))

        | (
                (real_time_quotes_now_sh['daily05'] >=
                 sh_small_normal_k_line_param['zt_chg'])
                & (real_time_quotes_now_sh['daily04'] >=
                   sh_small_normal_k_line_param['zt_chg'])
                & (real_time_quotes_now_sh['daily03'] >=
                   sh_small_normal_k_line_param['zt_chg'])
                & (real_time_quotes_now_sh['daily02'] >=
                   sh_small_normal_k_line_param['zt_chg'])
        )
        | (  # 05 04 02 涨停
                (real_time_quotes_now_sh['daily05'] >=
                 sh_small_normal_k_line_param['zt_chg'])
                & (real_time_quotes_now_sh['daily04'] >=
                   sh_small_normal_k_line_param['zt_chg'])
                & (real_time_quotes_now_sh['daily03'] <=
                   sh_small_normal_k_line_param['zt_chg'])
                & (real_time_quotes_now_sh['daily02'] >=
                   sh_small_normal_k_line_param['zt_chg'])
        )
        ]

    if data_frame_util.is_not_empty(real_time_quotes_now_sh_05_exclude):
        real_time_quotes_now_sh.loc[
            real_time_quotes_now_sh['symbol'].isin(list(real_time_quotes_now_sh_05_exclude['symbol'])),
            'exclude'] = True
    return real_time_quotes_now_sh



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd


def get_exclude_kpl_selection():
    return pd.DataFrame([
        ['801250', '并购重组', '财务概念', 'first_index'],
        ['801573', '三季报增长', '财务概念', 'first_index'],
        ['801787', '实控人变更', '财务概念', 'first_index'],
        ['801104', '开板次新', '财务概念', 'first_index'],
        ['801284', '举牌', '财务概念', 'first_index'],
        ['801628', '资产管理', '财务概念', 'first_index'],
        ['801452', '再融资', '财务概念', 'first_index'],
        ['801008', '高送转', '财务概念', 'first_index'],
        ['801162', '超跌', '财务概念', 'first_index'],
        ['801273', '股权转让', '财务概念', 'first_index'],
        ['801522', '专精特新', '财务概念', 'first_index'],
        ['801450', '年报预增', '财务概念', 'first_index'],
        ['801382', '分拆上市预期', '财务概念', 'first_index'],
        ['801251', '送转预期', '财务概念', 'first_index'],
        ['801122', '壳资源', '财务概念', 'first_index'],
        ['801198', '送转填权', '财务概念', 'first_index'],
        ['801366', '业绩增长', '财务概念', 'first_index'],
        ['801572', '中报增长', '财务概念', 'first_index'],
        ['801574', '年报增长', '财务概念', 'first_index'],
        ['801574', '年报增长', '财务概念', 'first_index'],
        ['801631', '次新股', '财务概念', 'first_index'],

        ['801166', '上海国资改革', '宏观概念', 'first_index'],
        ['801033', '国企改革', '宏观概念', 'first_index'],
        ['801032', '深圳国资改革', '宏观概念', 'first_index'],
        ['801363', '黑龙江自贸区', '宏观概念', 'first_index'],
        ['801417', '天津自贸区', '宏观概念', 'first_index'],
        ['801209', '振兴东北', '宏观概念', 'first_index'],
        ['801376', '健康中国', '宏观概念', 'first_index'],
        ['801733', '中特估', '宏观概念', 'first_index'],
        ['801530', '中字头', '宏观概念', 'first_index'],

        ['801606', '成渝经济圈', '地域概念', 'first_index'],
        ['801182', '雄安新区', '地域概念', 'first_index'],
        ['801306', '深圳', '地域概念', 'first_index'],
        ['801132', '粤港澳', '地域概念', 'first_index'],
        ['801319', '福建', '地域概念', 'first_index'],
        ['801651', '湖南', '地域概念', 'first_index'],
        ['801115', '海南', '地域概念', 'first_index'],
        ['801407', '上海', '地域概念', 'first_index'],
        ['801310', '浙江', '地域概念', 'first_index'],
        ['801457', '武汉', '地域概念', 'first_index'],
        ['801211', '新疆', '地域概念', 'first_index'],
    ], columns=['symbol',
                'name',
                'exclude_reason',
                'index_class'
                ])


def get_exclude_kpl_selection_simple():
    return pd.DataFrame([
        ['801250', '并购重组', '财务概念', 'first_index'],
        ['801573', '三季报增长', '财务概念', 'first_index'],
        ['801787', '实控人变更', '财务概念', 'first_index'],
        ['801104', '开板次新', '财务概念', 'first_index'],
        ['801284', '举牌', '财务概念', 'first_index'],
        ['801628', '资产管理', '财务概念', 'first_index'],
        ['801452', '再融资', '财务概念', 'first_index'],
        ['801008', '高送转', '财务概念', 'first_index'],
        ['801162', '超跌', '财务概念', 'first_index'],
        ['801273', '股权转让', '财务概念', 'first_index'],
        ['801522', '专精特新', '财务概念', 'first_index'],
        ['801382', '分拆上市预期', '财务概念', 'first_index'],
        ['801251', '送转预期', '财务概念', 'first_index'],
        ['801122', '壳资源', '财务概念', 'first_index'],
        ['801198', '送转填权', '财务概念', 'first_index'],
        ['801631', '次新股', '财务概念', 'first_index'],

    ], columns=['symbol',
                'name',
                'exclude_reason',
                'index_class'
                ])


if __name__ == '__main__':
    df = get_exclude_kpl_selection()
    print(df)
